% COMSOL results combined with experiments

clear all
close all

a  = 1E-6;    % bead radius [m]
mu = 10.093E-4; % water viscosity [Pa-s] *from COMSOL sim
t_m = 2.5E-9; % monolayer thickness [m]

filename1 = 'comsol.txt';
delimiterIn = '\t';
headerlinesIn = 1;
A1 = importdata(filename1,delimiterIn,headerlinesIn);


b  = A1.data(:,1);

m  = A1.data(:,2);

D  = A1.data(:,3);

U  = A1.data(:,4);

U  = 100-U; % adjust for moving control volume


b_d = (b*a)/mu; % dimensionless stress
Us = (1/(4*3.8))*((1/3.8)^2+3)*100;
U_d = U/Us;    % dimensionless velocity

D_c = scatteredInterpolant(b_d,m,D);
U_c = scatteredInterpolant(b_d,m,U_d);

[bq,mq] = meshgrid(logspace(-4,2,1000),logspace(0,5,1000));

Dq = D_c(bq,mq);
Uq = U_c(bq,mq);

%% Faxen's law (solid wall)
L_m = 1.1;
Fw_m = 1./(1 - (9/16).*(1./L_m) + (1/8).*(1./L_m).^3 - (45/256).*(1./L_m).^4 - (1/16).*(1./L_m).^5);

%% Model from Lee & Leal (1980, JFM) Table 2, viscosity ratio 0
Fs_m = 0.741287;

%% including experimental data

% from flow transmission (linear regression with 95% CI)
u_mix = (0.1213/0.2); %R^2 = 0.6253;
ue_mix_pos = (0.1449/0.2);
ue_mix_neg = (0.09781/0.2);
ue_mix = ue_mix_pos-u_mix;
u_DPPC = (5.355e-05/0.2); %R^2 = -0.004849;
ue_DPPC_pos = (0.002431/0.2);
ue_DPPC_neg = (-0.002324/0.2);
ue_DPPC = ue_DPPC_pos-u_DPPC;
u_DOPC = (0.1854/0.2); %R^2 = 0.8857;
ue_DOPC_pos = (0.1986/0.2);
ue_DOPC_neg = (0.1723/0.2);
ue_DOPC = ue_DOPC_pos-u_DOPC;

m_mix1 = mq(find(Uq < ue_mix_pos & Uq > ue_mix_neg));
m_DPPC1 = mq(find(Uq < ue_DPPC_pos & Uq > ue_DPPC_neg));
m_DOPC1 = mq(find(Uq < ue_DOPC_pos & Uq > ue_DOPC_neg));

b_mix1 = bq(find(Uq < ue_mix_pos & Uq > ue_mix_neg));
b_DPPC1 = bq(find(Uq < ue_DPPC_pos & Uq > ue_DPPC_neg));
b_DOPC1 = bq(find(Uq < ue_DOPC_pos & Uq > ue_DOPC_neg));

m_mix3 = mq(find(abs(Uq - u_mix)<10^(-2)));
m_DPPC3 = mq(find(abs(Uq - u_DPPC)<10^(-2)));
m_DOPC3 = mq(find(abs(Uq - u_DOPC)<ue_DOPC));

b_mix3 = bq(find(abs(Uq - u_mix)<10^(-2)));
b_DPPC3 = bq(find(abs(Uq - u_DPPC)<10^(-2)));
b_DOPC3 = bq(find(abs(Uq - u_DOPC)<ue_DOPC));

% from drag force (extrapolation, see drag_force.m)
d_mix = 1.2074;
de_mix = 0.0895;
d_DPPC = 1.4562;
de_DPPC = 0.1498;
d_DOPC = 1.1242;
de_DOPC = 0.0792;

m_mix2 = mq(find(Dq < d_mix+de_mix & Dq > d_mix-de_mix)); %/1.2074));
m_DPPC2 = mq(find(Dq < d_DPPC+de_DPPC & Dq > d_DPPC-de_DPPC)); %/1.4562));
m_DOPC2 = mq(find(Dq < d_DOPC+de_DOPC & Dq > d_DOPC-de_DOPC)); %/1.1242));

b_mix2 = bq(find(Dq < d_mix+de_mix & Dq > d_mix-de_mix)); %/1.2074));
b_DPPC2 = bq(find(Dq < d_DPPC+de_DPPC & Dq > d_DPPC-de_DPPC)); %/1.4562));
b_DOPC2 = bq(find(Dq < d_DOPC+de_DOPC & Dq > d_DOPC-de_DOPC)); %/1.1242));

m_mix4 = mq(find(abs(Dq - d_mix)<10^(-2)));
m_DPPC4 = mq(find(abs(Dq - d_DPPC)<10^(-2)));
m_DOPC4 = mq(find(abs(Dq - d_DOPC)<de_DOPC));

b_mix4 = bq(find(abs(Dq - d_mix)<10^(-2)));
b_DPPC4 = bq(find(abs(Dq - d_DPPC)<10^(-2)));
b_DOPC4 = bq(find(abs(Dq - d_DOPC)<de_DOPC));

jj=1;
for ii = 1:length(b_DPPC2)
    ind = find(b_DPPC1 == b_DPPC2(ii) & m_DPPC1 == m_DPPC2(ii));
    
    if isempty(ind)
    else
        b_ind_DPPC(jj) = ind;
        jj = jj+1;
    end
end

jj=1;
for ii = 1:length(b_DOPC2)
    ind = find(b_DOPC1 == b_DOPC2(ii) & m_DOPC1 == m_DOPC2(ii));
    
    if isempty(ind)
    else
        b_ind_DOPC(jj) = ind;
        jj = jj+1;
    end
end

jj=1;
for ii = 1:length(b_mix2)
    ind = find(b_mix1 == b_mix2(ii) & m_mix1 == m_mix2(ii));
    
    if isempty(ind)
    else
        b_ind_mix(jj) = ind;
        jj = jj+1;
    end
end

jj=1;
for ii = 1:length(b_DPPC4)
    ind = find(b_DPPC3 == b_DPPC4(ii) & m_DPPC3 == m_DPPC4(ii));
    
    if isempty(ind)
    else
        b_ind_DPPC_av(jj) = ind;
        jj = jj+1;
    end
end

jj=1;
for ii = 1:length(b_DOPC4)
    ind = find(b_DOPC3 == b_DOPC4(ii) & m_DOPC3 == m_DOPC4(ii));
    
    if isempty(ind)
    else
        b_ind_DOPC_av(jj) = ind;
        jj = jj+1;
    end
end

jj=1;
for ii = 1:length(b_mix4)
    ind = find(b_mix3 == b_mix4(ii) & m_mix3 == m_mix4(ii));
    
    if isempty(ind)
    else
        b_ind_mix_av(jj) = ind;
        jj = jj+1;
    end
end


%% Values for lipids
U  = 100E-6;  % bead velocity [m/s]

b_DPPC = mean(b_DPPC1(b_ind_DPPC))*(mu/a)
be_DPPC = std(b_DPPC1(b_ind_DPPC))*(mu/a)
b_DOPC = mean(b_DOPC1(b_ind_DOPC))*(mu/a)
be_DOPC = std(b_DOPC1(b_ind_DOPC))*(mu/a)
b_mix = mean(b_mix1(b_ind_mix))*(mu/a)
be_mix = std(b_mix1(b_ind_mix))*(mu/a)

m_DPPC = mean(m_DPPC1(b_ind_DPPC))*(mu)
me_DPPC = std(m_DPPC1(b_ind_DPPC))*(mu)
m_DOPC = mean(m_DOPC1(b_ind_DOPC))*(mu)
me_DOPC = std(m_DOPC1(b_ind_DOPC))*(mu)
m_mix = mean(m_mix1(b_ind_mix))*(mu)
me_mix = std(m_mix1(b_ind_mix))*(mu)


X_DPPC=b_DPPC1(b_ind_DPPC);
Y_DPPC=m_DPPC1(b_ind_DPPC);
k_DPPC = boundary(X_DPPC,Y_DPPC);

X_DOPC=b_DOPC1(b_ind_DOPC);
Y_DOPC=m_DOPC1(b_ind_DOPC);
k_DOPC = boundary(X_DOPC,Y_DOPC,1);

X_mix=b_mix1(b_ind_mix);
Y_mix=m_mix1(b_ind_mix);
k_mix = boundary(X_mix,Y_mix,1);


%% make it dimensional

bq_d = bq*(mu/a);
mq_d = (mq*mu)*(2*t_m);

figure
contourf(bq_d,mq_d,Dq,'LineStyle','none');
colormap('jet');
% caxis([Fs_m Fw_m])
colorbar
xlim([1E-1 1E5]);
ylim([1E-11 5E-7]);
% xlabel('b');
% ylabel('\eta');
xtkvct = 10.^(-1:5);
ytkvct = 10.^(-11:-7);
% xtkvct = 10.^(log10(min(min(bq_d))):log10(max(max(bq_d))));
% ytkvct = 10.^(round(log10(min(min(mq_d)))):round(log10(max(max(mq_d)))));
set(gca,'LineWidth',1.5,'FontSize',15,'YScale','log','XScale','log');
set(gca, 'XTick', xtkvct);
set(gca, 'XMinorTick','on')
set(gca, 'YTick', ytkvct);
set(gca, 'YMinorTick','on')

figure
contourf(bq_d,mq_d,Uq,'LineStyle','none');
colormap('jet');
caxis([0 1])
colorbar
xlim([1E-1 1E5]);
ylim([1E-11 5E-7]);
% xlabel('b');
% ylabel('\eta');
set(gca,'LineWidth',1.5,'FontSize',15,'YScale','log','XScale','log');
set(gca, 'XTick', xtkvct);
set(gca, 'XMinorTick','on')
set(gca, 'YTick', ytkvct);
set(gca, 'YMinorTick','on')

X_DOPC_u = unique(X_DOPC);
ii_max = length(X_DOPC_u);
for ii=1:ii_max
    k_ind = find(X_DOPC == X_DOPC_u(ii));
    Y_DOPC_u(ii) = max(Y_DOPC(k_ind));
    X_DOPC_u(ii+ii_max)=X_DOPC_u(ii_max+1-ii);
    Y_DOPC_u(ii+ii_max)=min(min(mq));
end

figure
h1=fill(X_DPPC(k_DPPC)*(mu/a),Y_DPPC(k_DPPC)*2*mu*t_m,'k','LineWidth',2);
h1.FaceAlpha = 0.5;
h1.EdgeAlpha = 0.5;
h1.EdgeColor = 'k';
hold on
plot(mean(b_DPPC3(b_ind_DPPC_av))*(mu/a),mean(m_DPPC3(b_ind_DPPC_av))*2*mu*t_m,'k^','MarkerSize',12,'LineWidth',1.5);
hold on
h2=fill(X_DOPC_u*(mu/a),Y_DOPC_u*2*mu*t_m,'b','LineWidth',2);
h2.FaceAlpha = 0.5;
h2.EdgeAlpha = 0.5;
h2.EdgeColor = 'b';
% hold on
% plot(mean(b_DOPC1(b_ind_DOPC))*(mu/a),mean(m_DOPC1(b_ind_DOPC))*2*mu*t_m,'bo','MarkerSize',12,'LineWidth',1.5);
hold on
h3=fill(X_mix(k_mix)*(mu/a),Y_mix(k_mix)*2*mu*t_m,[0 0.6 0],'LineWidth',2);
h3.FaceAlpha = 0.5;
h3.EdgeAlpha = 0.5;
h3.EdgeColor = [0 0.6 0];
hold on
plot(mean(b_mix3(b_ind_mix_av))*(mu/a),mean(m_mix3(b_ind_mix_av))*2*mu*t_m,'s','color',[0 0.6 0],'MarkerSize',12,'LineWidth',1.5);
hold on
[C1,h1]=contour(bq_d,mq_d,Dq,'--','LineWidth',1.5);
caxis([Fs_m Fw_m])
colormap('jet');
hold on
[C2,h2]=contour(bq_d,mq_d,Uq,'LineWidth',1.5);
caxis([0 1])
xlim([1E-1 1E5]);
ylim([1E-11 5E-7]);
colormap('jet');
% xlabel('b');
% ylabel('\eta');
colorbar
xtkvct = 10.^(-1:5);
set(gca,'LineWidth',1.5,'FontSize',15,'YScale','log','XScale','log');
set(gca, 'XTick', xtkvct);
set(gca, 'XMinorTick','on')
set(gca, 'YTick', ytkvct);
set(gca, 'YMinorTick','on')