% Drag force measurements

clear all
close all

load('drag_force_data')

%% group trials with 100um/s speed

% DOPC (F9, F10)
for ii = 1:numel(F9_100)
    F_100_DOPC(ii,1) = F9_100(ii,1);
    L_100_DOPC(ii,1) = L9_100(ii,1);
end

for ii = numel(F9_100)+1:numel(F9_100)+numel(F10_100)
    F_100_DOPC(ii,1) = F10_100(ii-numel(F9_100),1);
    L_100_DOPC(ii,1) = L10_100(ii-numel(F9_100),1);
end

L_100_u_DOPC = unique(L_100_DOPC);

F_100_av_DOPC = zeros(size(L_100_u_DOPC,1),1);
F_100_st_DOPC = zeros(size(L_100_u_DOPC,1),1);
F_100_md_DOPC = zeros(size(L_100_u_DOPC,1),1);
F_100_qt_DOPC = zeros(size(L_100_u_DOPC,1),1);

for i = 1:size(L_100_u_DOPC,1)
    j = find(L_100_DOPC == L_100_u_DOPC(i,1));
    
    F_100_av_DOPC(i,1) = mean(F_100_DOPC(j,1));
    F_100_st_DOPC(i,1) = std(F_100_DOPC(j,1));
    
    F_100_md_DOPC(i,1) = median(F_100_DOPC(j,1));
    F_100_qt_DOPC(i,1) = iqr(F_100_DOPC(j,1));
    
    clear j
end

% DOPC/DPPC (F1, F3)
for ii = 1:numel(F1_100)
    F_100_all(ii,1) = F1_100(ii,1);
    L_100_all(ii,1) = L1_100(ii,1);
end

for ii = numel(F1_100)+1:numel(F1_100)+numel(F3_100)
    F_100_all(ii,1) = F3_100(ii-numel(F1_100),1);
    L_100_all(ii,1) = L3_100(ii-numel(F1_100),1);
end

L_100_u_all = unique(L_100_all);

F_100_av_all = zeros(size(L_100_u_all,1),1);
F_100_st_all = zeros(size(L_100_u_all,1),1);
F_100_md_all = zeros(size(L_100_u_all,1),1);
F_100_qt_all = zeros(size(L_100_u_all,1),1);

for i = 1:size(L_100_u_all,1)
    j = find(L_100_all == L_100_u_all(i,1));
    
    F_100_av_all(i,1) = mean(F_100_all(j,1));
    F_100_st_all(i,1) = std(F_100_all(j,1));
    
    F_100_md_all(i,1) = median(F_100_all(j,1));
    F_100_qt_all(i,1) = iqr(F_100_all(j,1));
    
    clear j
end

% DPPC (F12 {1 micron}, F13, F14)
for ii = 1:numel(F13_100)
    F_100_DPPC(ii,1) = F13_100(ii,1);
    L_100_DPPC(ii,1) = L13_100(ii,1);
end

for ii = numel(F13_100)+1:numel(F13_100)+numel(F12_100)
    F_100_DPPC(ii,1) = F12_100(ii-numel(F13_100),1);
    L_100_DPPC(ii,1) = L12_100(ii-numel(F13_100),1);
end

for ii = numel(F13_100)+numel(F12_100)+1:numel(F13_100)+numel(F12_100)+numel(F14_100)
    F_100_DPPC(ii,1) = F14_100(ii-numel(F13_100)-numel(F12_100),1);
    L_100_DPPC(ii,1) = L14_100(ii-numel(F13_100)-numel(F12_100),1);
end

L_100_u_DPPC = unique(L_100_DPPC);

F_100_av_DPPC = zeros(size(L_100_u_DPPC,1),1);
F_100_st_DPPC = zeros(size(L_100_u_DPPC,1),1);
F_100_md_DPPC = zeros(size(L_100_u_DPPC,1),1);
F_100_qt_DPPC = zeros(size(L_100_u_DPPC,1),1);

for i = 1:size(L_100_u_DPPC,1)
    j = find(L_100_DPPC == L_100_u_DPPC(i,1));
    
    F_100_av_DPPC(i,1) = mean(F_100_DPPC(j,1));
    F_100_st_DPPC(i,1) = std(F_100_DPPC(j,1));
    
    F_100_md_DPPC(i,1) = median(F_100_DPPC(j,1));
    F_100_qt_DPPC(i,1) = iqr(F_100_DPPC(j,1));
    
    clear j
end

%% Plot using dots with errorbar and with fluid slip fitting (100 um/s data)
a_DPPC = 0.8361; %R^2 = 0.7574
a_DOPC = 151.1; %R^2 = 0.0004859
a_mix = 3.444; %R^2 = 0.4902
F_DPPC_m = 1./(1 - (9/16).*(1./(L_m+a_DPPC)) + (1/8).*(1./(L_m+a_DPPC)).^3 - (45/256).*(1./(L_m+a_DPPC)).^4 - (1/16).*(1./(L_m+a_DPPC)).^5);
F_DOPC_m = 1./(1 - (9/16).*(1./(L_m+a_DOPC)) + (1/8).*(1./(L_m+a_DOPC)).^3 - (45/256).*(1./(L_m+a_DOPC)).^4 - (1/16).*(1./(L_m+a_DOPC)).^5);
F_mix_m = 1./(1 - (9/16).*(1./(L_m+a_mix)) + (1/8).*(1./(L_m+a_mix)).^3 - (45/256).*(1./(L_m+a_mix)).^4 - (1/16).*(1./(L_m+a_mix)).^5);

figure
e0=errorbar(Lw_u,Fw_av,Fw_st,'rx','MarkerSize',10,'LineWidth',2);
hold on
p0=plot(L_m,Fw_m,'r:','LineWidth',2);
hold on

e1=errorbar(L_100_u_DPPC,F_100_av_DPPC,F_100_st_DPPC,'k^','MarkerSize',10,'LineWidth',2);
hold on
p1=plot(L_m,F_DPPC_m,'k:','LineWidth',2);
hold on

e2=errorbar(L_100_u_DOPC,F_100_av_DOPC,F_100_st_DOPC,'bo','MarkerSize',10,'LineWidth',2);
hold on
p2=plot(L_m,F_DOPC_m,'b:','LineWidth',2);
hold on

e3=errorbar(L_100_u_all,F_100_av_all,F_100_st_all,'s','color',[0 .6 0],'MarkerSize',10,'LineWidth',2);
hold on
p3=plot(L_m,F_mix_m,'g:','color',[0 .6 0],'LineWidth',2);

leg=legend([e0;p0;e1;p1;e2;p2;e3;p3],'Solid wall (data)','Solid wall (Eq. 1, l_s = 0)', ...
    'DPPC (data)','DPPC (Eq. 1, l_s = 0.83 a)', ...
    'DOPC (data)','DOPC (Eq. 1, l_s = 150 a)', ...
    'DOPC/DPPC (data)','DOPC/DPPC (Eq. 1, l_s = 3.4 a)', ...
    'Location','NorthEast');
xlabel('d/a','FontSize',15);
ylabel('Drag ratio','FontSize',15);
grid on
ylim([0.8 2.4]);
xlim([0.8 8]);
set(leg,'FontSize',15);
set(gca,'LineWidth',2,'FontSize',20,'YScale','linear');


%% Extrapolate to L=1.1a to compare with COMSOL
L=1.1;

D_ex_all = interp1(L_100_u_all,F_100_av_all,L,'nearest', 'extrap')
e_ex_all = interp1(L_100_u_all,F_100_st_all,L,'nearest', 'extrap')
D_ex_DPPC = interp1(L_100_u_DPPC,F_100_av_DPPC,L,'nearest', 'extrap')
e_ex_DPPC = interp1(L_100_u_DPPC,F_100_st_DPPC,L,'nearest', 'extrap')
D_ex_DOPC = interp1(L_100_u_DOPC,F_100_av_DOPC,L,'nearest', 'extrap')
e_ex_DOPC = interp1(L_100_u_DOPC,F_100_st_DOPC,L,'nearest', 'extrap')